/*
 * Copyright (C) 2018 thomaskneisel
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package pictureoptimizer;

import java.lang.String;

/**
 * A base class for the selection of individuals when a new generation is 
 * generated.
 * 
 * The base also implements a dummy implementation which makes the probability
 * of selection idetnical for all memebers of a generation
 * 
 * @author thomaskneisel
 */
public class Selection {

    protected Selection() {
    }
	
	/**
	 * Generate the weights for the weighted rouellte wheel
	 * Sum of all weights must be 1. !
	 * 
	 * @param fitness fitness values of all members
	 * @return weights
	 */
    public double[] normalise(int fitness[]) {
        double[] rouletteWheel = new double[fitness.length];
        for (int i = 0; i < rouletteWheel.length; i++) {
            rouletteWheel[i] = 1. / rouletteWheel.length;
        }
        return rouletteWheel;
    }
	/**
	 * Return type info in human readable form
	 *
	 * @return type of Selection (to be overriden)
	 */
    public String info() {
        return "dummy";
    }

	/**
	 * Create a Selection object where type of derived class is 
	 * given as String parameter. Supported types:
	 * <dl>
	 *   <dt> WinnerTakesItAll
	 *   </dt>
	 *   <dd> Only the indicviduum with the highest fitnes will survive
	 *   </dd>
	 *   <dt>dummy implementation (everthing else)
	 *   </dt>
	 *   <dd>all inidividuals will be handeled equals
	 *   </dd>
	 * </dl>
	 * 
	 * @param selectionType type of Selection
	 * @return Selection Object of requested type or default
	 */
    public static Selection createSelection(String selectionType) {
        Selection r = null;
        if (selectionType.toUpperCase().equals("WINNERTAKESITALL")) {
            r =  new WinnerTakesItAll();
        }
		else
			r =  new Selection();
        return r;
    }
}
