/*
 * Copyright (C) 2018 thomaskneisel
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package pictureoptimizer;

/**
 * Create a weighed roulettewheel where the first (best) member wins always.
 * As a consequence, cross over is no longer effective.
 *
 * @author thomaskneisel
 */
public class WinnerTakesItAll extends Selection {

    protected WinnerTakesItAll() {
        ;
    }

	/**
	 * Generate the weights for the weighted roulette wheel
	 * Probability of best member will be 100%, for all other members 0%
	 * 
	 * @param fitness fitness values of all members
	 * @return weights
	 */
	@Override
    public double[] normalise(int fitness[]) {
        double[] rouletteWheel = new double[fitness.length];
        for (int i = 0; i < fitness.length; i++) {
            rouletteWheel[i] = 1.0;
        }
        return rouletteWheel;
    }

	/**
	* Return type info in human readable form
	 *
	 * @return type of Selection (to be overriden)
	 */
	@Override
    public String info() {
        return "WinnerTakesItAll";
    }
}
